<?php

/**
 * Object that provides simple access to values inside Excel spreadsheets.
 * Depends on http://code.google.com/p/php-excel-reader/
 */

require_once dirname(__FILE__) . '/php-excel-reader/excel_reader2.php';

class ExcelSimpleParser {
  private $data;
  private $current_sheet = 0;
  
  function ExcelSimpleParser($filename) {
    $this->data = new Spreadsheet_Excel_Reader($filename);
  }

  /**
   * Return an array of sheet indexes and names.
   * @return array
   */
  function getSheets() {
    $result = array();
    #print_r($this->data->boundsheets);
    foreach ($this->data->boundsheets as $sheet_index => $sheet_info) {
      $result[$sheet_index] = $sheet_info['name'];
    }
    return $result;
  }

  /**
   * Set the current sheet.
   * @param int $sheet_index
   */
  public function setSheetByIndex($sheet_index) {
    if (isset($this->data->boundsheets[$sheet_index])) {
      $this->current_sheet = $sheet_index;
      return TRUE;
    }
    return FALSE;
  }

  public function setSheetByName($sheet_name) {
    $sheets = $this->getSheets();
    foreach ($sheets as $index => $name) {
      if ($name == $sheet_name) {
        $this->setSheetByIndex($index);
        return TRUE;
      }
    }
    return FALSE;
  }

  /**
   * Return a single cell value.
   * @param <type> $x
   * @param <type> $y
   * @param <type> $sheet_index
   * @return string
   */
  /*
  public function getCell($x, $y, $sheet_index) {
    $cells = getCellsHoriz(1, $x, $y);
    return $cells[0];
  }
   * 
   */

  /**
   * Return a one-dimensional array of cell values.
   * @param <type> $count
   * @param <type> $x
   * @param <type> $y
   * @return array
   */
  public function getCellsHoriz($count = 1, $x, $y) {
    $cells = array();
    if (!isset($this->data->boundsheets)) {
      return $cells;
    }
    foreach ($this->data->sheets[$this->current_sheet]['cells'][$y] as $col_index => $value) {
      #echo "$col_index => $value\n";
      if ($col_index >= $x && $col_index < $x + $count) {
        $cells[] = utf8_encode($value);
      }
    }
    if (empty($cells)) {
      #dsm("DEBUG: getCellsHoriz($count, $x, $y)");
    }
    #print_r($cells);
    return $cells;
  }

  /**
   * Return a 2-dimensional array of cell values.
   * 
   * @param <type> $width
   * @param <type> $height
   * @param <type> $x
   * @param <type> $y
   * @return array
   */
  public function getCellsRegion($width, $height, $x, $y) {
    $rows = array();
    for ($y_index = $y; $y_index < $y + $height; $y_index++) {
      $rows[] = $this->getCellsHoriz($width, $x, $y_index);
    }
    return $rows;
  }

  public function getCellsAll() {
    $cells = array();
    foreach ($this->data->sheets[$this->current_sheet]['cells'] as $row_index => $row_data) {
      foreach ($row_data as $col_index => $value) {
        $cells[$row_index-1][$col_index-1] = utf8_encode($value);
      }
    }
    return $cells;
  }
}
